#include <xc.h>
#include <plib.h>
#include "APP001_LCD.h"

#define _XTAL_FREQ 1000000

void interrupt HighISR(void)        // XC8 高優先權中斷函數
{
    if (TMR0IE && TMR0IF)
    {
        WriteTimer0(65535-487);     // 500mS Period, 500mS/4uS/256 = 488
        LATD0 = !LATD0;             // LED1 (D1) 250mS 轉態一次
        TMR0IF=0;                   // 清除 Timer0 的中斷旗號
    }
}

void interrupt low_priority LowISR(void)    // XC8 低優先權中斷函數
{
    if (TMR1IF && TMR1IE)
    {
        WriteTimer1(65535-7811);    // 250mS Period, 250mS/4uS/8 = 7812
        LATD7 = !LATD7;             // LED7 (D8) 500mS 轉態一次
        TMR1IF = 0;                 // 清除 Timer1 的中斷旗號
    }
}

void main(void)
{
    OSCCONbits.IRCF = 0b011;    // Select INTOSC at 1MHz as clock source
                                // Tcy = 4uS (Fcy = 250KHz)
    
//  設定 Timer0 及 Timer1 的工作需求    
    T0CON = 0x00;
    T0CON = 0b10000111;         // 啟動 Timer0 使用 16-bit Mode, 預除器 1: 256
    WriteTimer0(65535-487);     // 500mS Period, 500mS/4uS/256 = 488
    TMR0IP = 1;                 // 設定 Timer0 為高優先權中斷
    TMR0IE = 1;                 // 啟用 Timer0 的中斷
    
    T1CON = 0x00;
    T1CON = 0b00110111;         // 啟動 Timer1, 使用 16-bit Mode, 預除器 1:8
    WriteTimer1(65535-7811);    // 250mS Period, 250mS/4uS/8 = 7812
    TMR1IP = 0;                 // 設定 Timer1 為低優先權中斷
    TMR1IE = 1;                 // 啟用 Timer1 的中斷
    
  // 開啟高、低優先權的中斷功能      
    IPEN = 1;                   // 啟用高、低優先權中斷功能
    GIEH = 1;                   // 開啟高優先權中斷
    GIEL = 1;                   // 開起低優先權中斷
 
    // LCD 使用到的 I/O 腳位初始設定
    ANSA2 = 0;                  // 關閉 RA2 的類比輸入功能
    TRISA2 = 0;                 // RA2 設為輸出腳位
    ANSELD = 0;                 // 關閉 PORTD 的類比輸入功能
    TRISD = 0x00;               // PORTD 設為輸出腳位
 
// LCD 模組的初始及顯示控制    
    LCD_L_Delay();              // 開機 LCD 延遲 10mS    
    OpenLCD();                  // LCD 模組的初始化函數
    LCD_Set_Cursor (0, 0);      // 設定 LCD 要顯示的位置在(第一行第一個位置)
    putrsLCD((const far char*) "Lab4 T0 & T1 Int");
    LCD_Set_Cursor (1, 0);      // 設定 LCD 要顯示的位置在(第二行第一個位置)
    putrsLCD((const far char*) "T0=0.5S T1=125mS");

    LATD = 0x00;                // Turn Off all LEDs
    
    while(1);
}

